==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/PodReadinessGateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PodReadinessGateFluentImpl<A extends io.fabric8.kubernetes.api.model.PodReadinessGateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PodReadinessGateFluent<A>{
  public PodReadinessGateFluentImpl() {
  }
  public PodReadinessGateFluentImpl(io.fabric8.kubernetes.api.model.PodReadinessGate instance) {
    this.withConditionType(instance.getConditionType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String conditionType;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConditionType() {
    return this.conditionType;
  }
  public A withConditionType(java.lang.String conditionType) {
    this.conditionType=conditionType; return (A) this;
  }
  public java.lang.Boolean hasConditionType() {
    return this.conditionType != null;
  }
  
  /**
   * Method is deprecated. use withConditionType instead.
   */
  @java.lang.Deprecated
  public A withNewConditionType(java.lang.String arg0) {
    return (A)withConditionType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodReadinessGateFluentImpl that = (PodReadinessGateFluentImpl) o;
    if (conditionType != null ? !conditionType.equals(that.conditionType) :that.conditionType != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditionType,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PodReadinessGateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class PodReadinessGateFluentImpl<A extends io.fabric8.kubernetes.api.model.PodReadinessGateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.PodReadinessGateFluent<A>{
  public PodReadinessGateFluentImpl() {
  }
  public PodReadinessGateFluentImpl(io.fabric8.kubernetes.api.model.PodReadinessGate instance) {
    this.withConditionType(instance.getConditionType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String conditionType;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConditionType() {
    return this.conditionType;
  }
  public A withConditionType(java.lang.String conditionType) {
    this.conditionType=conditionType; return (A) this;
  }
  public java.lang.Boolean hasConditionType() {
    return this.conditionType != null;
  }
  
  /**
   * Method is deprecated. use withConditionType instead.
   */
  @java.lang.Deprecated
  public A withNewConditionType(java.lang.String arg0) {
    return (A)withConditionType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodReadinessGateFluentImpl that = (PodReadinessGateFluentImpl) o;
    if (conditionType != null ? !conditionType.equals(that.conditionType) :that.conditionType != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditionType,  additionalProperties,  super.hashCode());
  }
  
}
